@@ -19,7 +19,7 @@ from subprocess import call
 
 from datalad.cmd import Runner
 
-from datalad.api import add
+from datalad.api import save
 from datalad.api import create
 from datalad.api import create_test_dataset
 from datalad.api import Dataset
@@ -137,4 +137,4 @@ class runner(SuprocBenchmarks):
     #                               log_stdout='offline',
     #                               log_stderr='offline')
 
-    # TODO: track the one with in/out, i.e. for those BatchedProcesses
\ No newline at end of file
+    # TODO: track the one with in/out, i.e. for those BatchedProcesses
