@@ -9,24 +9,17 @@
 
 """
 
-
-from datalad.tests.utils import (
-    get_datasets_topdir,
-    integration,
-    slow
-)
-
 import logging
-import os
 import os.path as op
+import stat
 
 from unittest.mock import patch
 
 from datalad.config import ConfigManager
 from datalad import consts
 from datalad.api import (
-    create,
     clone,
+    create,
     remove,
 )
 from datalad.utils import (
@@ -39,37 +32,46 @@ from datalad.support.gitrepo import GitRepo
 from datalad.support.annexrepo import AnnexRepo
 from datalad.cmd import Runner
 from datalad.tests.utils import (
-    create_tree,
-    with_tempfile,
-    assert_in,
-    with_tree,
-    with_testrepos,
-    eq_,
-    neq_,
-    ok_,
     assert_false,
-    ok_file_has_content,
+    assert_in,
+    assert_message,
     assert_not_in,
     assert_raises,
-    assert_status,
-    assert_message,
+    assert_repo_status,
     assert_result_count,
     assert_result_values_equal,
-    ok_startswith,
-    assert_repo_status,
-    serve_path_via_http,
-    swallow_logs,
-    use_cassette,
-    skip_if_no_network,
-    skip_if,
-    with_sameas_remote,
+    assert_status,
+    create_tree,
+    DEFAULT_BRANCH,
+    eq_,
+    get_datasets_topdir,
+    integration,
     known_failure,
     known_failure_appveyor,
+    neq_,
+    nok_,
+    ok_,
+    ok_file_has_content,
+    has_symlink_capability,
+    ok_startswith,
     patch_config,
+    set_date,
+    serve_path_via_http,
+    skip_if_no_network,
+    skip_if_on_windows,
+    skip_ssh,
+    slow,
+    swallow_logs,
+    use_cassette,
+    with_sameas_remote,
+    with_tempfile,
+    with_testrepos,
+    with_tree,
+    SkipTest,
 )
 from datalad.core.distributed.clone import (
-    decode_source_spec,
     _get_installationpath_from_url,
+    decode_source_spec,
 )
 from datalad.distribution.dataset import Dataset
 
@@ -321,21 +323,58 @@ def test_failed_clone(dspath):
                    res)
 
 
-@with_testrepos('submodule_annex', flavors=['local'])
 @with_tempfile(mkdir=True)
-def test_reckless(src, top_path):
-    ds = clone(src, top_path, reckless=True,
+@with_tempfile(mkdir=True)
+@with_tempfile(mkdir=True)
+def check_reckless(annex, src_path, top_path, sharedpath):
+    # super with or without annex
+    src = Dataset(src_path).create(annex=annex)
+    # sub always with annex
+    srcsub = src.create('sub')
+
+    # and for the actual test
+    ds = clone(src.path, top_path, reckless=True,
                result_xfm='datasets', return_type='item-or-list')
-    eq_(ds.config.get('annex.hardlink', None), 'true')
+
+    is_crippled = srcsub.repo.is_managed_branch()
+
+    if annex and not is_crippled:
+        eq_(ds.config.get('annex.hardlink', None), 'true')
+
     # actual value is 'auto', because True is a legacy value and we map it
     eq_(ds.config.get('datalad.clone.reckless', None), 'auto')
-    eq_(ds.repo.repo_info()['untrusted repositories'][0]['here'], True)
+    if annex:
+        eq_(ds.repo.repo_info()['untrusted repositories'][0]['here'], True)
     # now, if we clone another repo into this one, it will inherit the setting
     # without having to provide it explicitly
-    sub = ds.clone(src, 'sub', result_xfm='datasets', return_type='item-or-list')
-    eq_(sub.config.get('datalad.clone.reckless', None), 'auto')
-    eq_(sub.config.get('annex.hardlink', None), 'true')
+    newsub = ds.clone(srcsub, 'newsub', result_xfm='datasets', return_type='item-or-list')
+    # and `get` the original subdataset
+    origsub = ds.get('sub', result_xfm='datasets', return_type='item-or-list')
+    for sds in (newsub, origsub):
+        eq_(sds.config.get('datalad.clone.reckless', None), 'auto')
+        if not is_crippled:
+            eq_(sds.config.get('annex.hardlink', None), 'true')
 
+    if is_crippled:
+        raise SkipTest("Remainder of test needs proper filesystem permissions")
+
+    if annex:
+        # the standard setup keeps the annex locks accessible to the user only
+        nok_((ds.pathobj / '.git' / 'annex' / 'index.lck').stat().st_mode \
+             & stat.S_IWGRP)
+        # but we can set it up for group-shared access too
+        sharedds = clone(
+            src, sharedpath,
+            reckless='shared-group',
+            result_xfm='datasets',
+            return_type='item-or-list')
+        ok_((sharedds.pathobj / '.git' / 'annex' / 'index.lck').stat().st_mode \
+            & stat.S_IWGRP)
+
+
+def test_reckless():
+    yield check_reckless, True
+    yield check_reckless, False
 
 @with_tempfile
 @with_tempfile
@@ -365,7 +404,6 @@ def test_clone_isnt_a_smartass(origin_path, path):
     eq_(cloned.subdatasets(), [])
 
 
-@skip_if(on_windows or not os.geteuid(), "Will fail under super-user")
 @with_tempfile(mkdir=True)
 def test_clone_report_permission_issue(tdir):
     pdir = Path(tdir) / 'protected'
@@ -373,6 +411,16 @@ def test_clone_report_permission_issue(tdir):
     # make it read-only
     pdir.chmod(0o555)
     with chpwd(pdir):
+        # first check the premise of the test. If we can write (strangely
+        # mounted/crippled file system, subsequent assumptions are violated
+        # and we can stop
+        probe = Path('probe')
+        try:
+            probe.write_text('should not work')
+            raise SkipTest
+        except PermissionError:
+            # we are indeed in a read-only situation
+            pass
         res = clone('///', result_xfm=None, return_type='list', on_failure='ignore')
         assert_status('error', res)
         assert_result_count(
@@ -505,13 +553,13 @@ def test_cfg_originorigin(path):
     # Clone another level, this time with a relative path. Drop content from
     # lev2 so that origin is the only place that the file is available from.
     clone_lev2.drop("file1.txt")
-    with chpwd(path), swallow_logs(new_level=9) as cml:
+    with chpwd(path), swallow_logs(new_level=logging.DEBUG) as cml:
         clone_lev3 = clone('clone_lev2', 'clone_lev3')
         # we called git-annex-init; see gh-4367:
-        cml.assert_logged(msg=r"[^[]*Running: \[('git', 'annex'|'git-annex'), "
+        cml.assert_logged(msg=r"[^[]*Async run \[('git', 'annex'|'git-annex'), "
                               r"'init'",
                           match=False,
-                          level='Level 9')
+                          level='DEBUG')
     assert_result_count(
         clone_lev3.get('file1.txt', on_failure='ignore'),
         1,
@@ -607,6 +655,19 @@ def test_decode_source_spec():
     # not a dataset UUID
     assert_raises(ValueError, decode_source_spec, 'ria+http://example.com#123')
 
+    # literal dataset name/location
+    eq_(decode_source_spec('ria+http://example.com#~rootds'),
+        {'source': 'ria+http://example.com#~rootds',
+         'version': None, 'type': 'ria',
+         'giturl': 'http://example.com/alias/rootds',
+         'default_destpath': 'rootds'})
+    # version etc still works
+    eq_(decode_source_spec('ria+http://example.com#~rootds@specialbranch'),
+        {'source': 'ria+http://example.com#~rootds@specialbranch',
+         'version': 'specialbranch', 'type': 'ria',
+         'giturl': 'http://example.com/alias/rootds',
+         'default_destpath': 'rootds'})
+
 
 def _move2store(storepath, d):
     # make a bare clone of it into a local that matches the organization
@@ -618,6 +679,7 @@ def _move2store(storepath, d):
     Runner(cwd=store_loc).run(['git', 'update-server-info'])
 
 
+@slow  # 12sec on Yarik's laptop
 @with_tree(tree={
     'ds': {
         'test.txt': 'some',
@@ -664,7 +726,7 @@ def test_ria_http(lcl, storepath, url):
             eq_(origds.repo.get_hexsha(), cloneds.repo.get_hexsha())
         ok_(cloneds.config.get('remote.origin.url').startswith(url))
         eq_(cloneds.config.get('remote.origin.annex-ignore'), 'true')
-        eq_(cloneds.config.get('datalad.get.subdataset-source-candidate-origin'),
+        eq_(cloneds.config.get('datalad.get.subdataset-source-candidate-200origin'),
             'ria+%s#{id}' % url)
 
     # now advance the source dataset
@@ -717,10 +779,184 @@ def test_ria_http(lcl, storepath, url):
     # ... the clone candidates go with the label-based URL such that
     # future get() requests acknowlege a (system-wide) configuration
     # update
-    eq_(cloned_by_label.config.get('datalad.get.subdataset-source-candidate-origin'),
+    eq_(cloned_by_label.config.get('datalad.get.subdataset-source-candidate-200origin'),
         'ria+ssh://somelabel#{id}')
 
+    if not has_symlink_capability():
+        return
+    # place a symlink in the store to serve as a dataset alias
+    (storepath / 'alias').mkdir()
+    (storepath / 'alias' / 'myname').symlink_to(storeds_loc)
+    with chpwd(lcl):
+        cloned_by_alias = clone('ria+{}#~{}'.format(url, 'myname'))
+    # still get the same data
+    eq_(cloned_by_alias.id, ds.id)
+    # more sensible default install path
+    eq_(cloned_by_alias.pathobj.name, 'myname')
 
+
+@with_tempfile
+def _test_ria_postclonecfg(url, dsid, clone_path):
+    # Test cloning from RIA store while ORA special remote autoenabling failed
+    # due to an invalid URL from the POV of the cloner.
+    # Origin's git-config-file should contain the UUID to enable. This needs to
+    # work via HTTP, SSH and local cloning.
+
+    # Autoenabling should fail initially by git-annex-init and we would report
+    # on INFO level. Only postclone routine would deal with it.
+    with swallow_logs(new_level=logging.INFO) as cml:
+        # First, the super ds:
+        riaclone = clone('ria+{}#{}'.format(url, dsid), clone_path)
+        cml.assert_logged(msg="access to 1 dataset sibling store-storage not "
+                              "auto-enabled",
+                          level="INFO",
+                          regex=False)
+
+    # However, we now can retrieve content since clone should have enabled the
+    # special remote with new URL (or origin in case of HTTP).
+    res = riaclone.get('test.txt')
+    assert_result_count(res, 1,
+                        status='ok',
+                        path=str(riaclone.pathobj / 'test.txt'),
+                        message="from {}...".format("origin"
+                                                    if url.startswith('http')
+                                                    else "store-storage"))
+
+    # same thing for the sub ds (we don't need a store-url and id - get should
+    # figure those itself):
+    with swallow_logs(new_level=logging.INFO) as cml:
+        riaclonesub = riaclone.get(
+            op.join('subdir', 'subds'), get_data=False,
+            result_xfm='datasets', return_type='item-or-list')
+        cml.assert_logged(msg="access to 1 dataset sibling store-storage not "
+                              "auto-enabled",
+                          level="INFO",
+                          regex=False)
+    res = riaclonesub.get('testsub.txt')
+    assert_result_count(res, 1,
+                        status='ok',
+                        path=str(riaclonesub.pathobj / 'testsub.txt'),
+                        message="from {}...".format("origin"
+                                                    if url.startswith('http')
+                                                    else "store-storage"))
+
+    # finally get the plain git subdataset.
+    # Clone should figure to also clone it from a ria+ URL
+    # (subdataset-source-candidate), notice that there wasn't an autoenabled ORA
+    # remote, but shouldn't stumble upon it, since it's a plain git.
+    res = riaclone.get(op.join('subdir', 'subgit', 'testgit.txt'))
+    assert_result_count(res, 1, status='ok', type='dataset', action='install')
+    assert_result_count(res, 1, status='notneeded', type='file')
+    assert_result_count(res, 2)
+
+
+@with_tempfile
+def _postclonetest_prepare(lcl, storepath, link):
+
+    from datalad.customremotes.ria_utils import (
+        create_store,
+        create_ds_in_store,
+        get_layout_locations
+    )
+    from datalad.distributed.ora_remote import (
+        LocalIO,
+    )
+
+    create_tree(lcl,
+                tree={
+                        'ds': {
+                            'test.txt': 'some',
+                            'subdir': {
+                                'subds': {'testsub.txt': 'somemore'},
+                                'subgit': {'testgit.txt': 'even more'}
+                            },
+                        },
+                      })
+
+    # create a local dataset with a subdataset
+    lcl = Path(lcl)
+    storepath = Path(storepath)
+    link = Path(link)
+    link.symlink_to(storepath)
+    subds = Dataset(lcl / 'ds' / 'subdir' / 'subds').create(force=True)
+    subds.save()
+    # add a plain git dataset as well
+    subgit = Dataset(lcl / 'ds' / 'subdir' / 'subgit').create(force=True,
+                                                              no_annex=True)
+    subgit.save()
+    ds = Dataset(lcl / 'ds').create(force=True)
+    ds.save(version_tag='original')
+    assert_repo_status(ds.path)
+
+    io = LocalIO()
+    create_store(io, storepath, '1')
+
+    # URL to use for upload. Point is, that this should be invalid for the clone
+    # so that autoenable would fail. Therefore let it be based on a to be
+    # deleted symlink
+    upl_url = "ria+{}".format(link.as_uri())
+
+    for d in (ds, subds, subgit):
+
+        # TODO: create-sibling-ria required for config! => adapt to RF'd
+        #       creation (missed on rebase?)
+        create_ds_in_store(io, storepath, d.id, '2', '1')
+        d.create_sibling_ria(upl_url, "store")
+
+        if d is not subgit:
+            # Now, simulate the problem by reconfiguring the special remote to
+            # not be autoenabled.
+            # Note, however, that the actual intention is a URL, that isn't
+            # valid from the point of view of the clone (doesn't resolve, no
+            # credentials, etc.) and therefore autoenabling on git-annex-init
+            # when datalad-cloning would fail to succeed.
+            Runner(cwd=d.path).run(['git', 'annex', 'enableremote',
+                                    'store-storage',
+                                    'autoenable=false'])
+        d.push('.', to='store')
+        store_loc, _, _ = get_layout_locations(1, storepath, d.id)
+        Runner(cwd=str(store_loc)).run(['git', 'update-server-info'])
+
+    link.unlink()
+    # We should now have a store with datasets that have an autoenabled ORA
+    # remote relying on an inaccessible URL.
+    # datalad-clone is supposed to reconfigure based on the URL we cloned from.
+    # Test this feature for cloning via HTTP, SSH and FILE URLs.
+
+    return ds.id
+
+
+@slow  # 14 sec on travis
+def test_ria_postclonecfg():
+
+    if not has_symlink_capability():
+        # This is needed to create an ORA remote using an URL for upload,
+        # that is then invalidated later on (delete the symlink it's based on).
+        raise SkipTest("Can't create symlinks")
+
+    from datalad.utils import make_tempfile
+    from datalad.tests.utils import HTTPPath
+
+    with make_tempfile(mkdir=True) as lcl, make_tempfile(mkdir=True) as store:
+        id = _postclonetest_prepare(lcl, store)
+
+        # test cloning via ria+file://
+        yield _test_ria_postclonecfg, Path(store).as_uri(), id
+
+        # Note: HTTP disabled for now. Requires proper implementation in ORA
+        #       remote. See
+        # https://github.com/datalad/datalad/pull/4203#discussion_r410284649
+
+        # # test cloning via ria+http://
+        # with HTTPPath(store) as url:
+        #     yield _test_ria_postclonecfg, url, id
+
+        # test cloning via ria+ssh://
+        yield skip_ssh(_test_ria_postclonecfg), \
+            "ssh://datalad-test:{}".format(Path(store).as_posix()), id
+
+
+@slow  # 17sec on Yarik's laptop
 @with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
 @serve_path_via_http
@@ -756,7 +992,7 @@ def test_inherit_src_candidates(lcl, storepath, url):
     eq_(len(datasets), 2)
     for ds in datasets:
         eq_(ConfigManager(dataset=ds, source='dataset-local').get(
-            'datalad.get.subdataset-source-candidate-origin'),
+            'datalad.get.subdataset-source-candidate-200origin'),
             'ria+%s#{id}' % url)
 
 
@@ -769,6 +1005,79 @@ def test_ria_http_storedataladorg(path):
     eq_(ds.id, datalad_store_testds_id)
 
 
+@skip_if_on_windows  # see gh-4131
+@with_tree(tree={
+    'ds': {
+        'test.txt': 'some',
+        'subdir': {'testsub.txt': 'somemore'},
+    },
+})
+@with_tempfile
+@with_tempfile
+def test_ephemeral(origin_path, clone1_path, clone2_path):
+
+    file_test = Path('ds') / 'test.txt'
+    file_testsub = Path('ds') / 'subdir' / 'testsub.txt'
+
+    origin = Dataset(origin_path).create(force=True)
+    if origin.repo.is_managed_branch():
+        raise SkipTest('Ephemeral clones cannot use adjusted mode repos')
+
+    origin.save()
+    # 1. clone via path
+    clone1 = clone(origin_path, clone1_path, reckless='ephemeral')
+
+    can_symlink = has_symlink_capability()
+
+    if can_symlink:
+        clone1_annex = (clone1.repo.dot_git / 'annex')
+        ok_(clone1_annex.is_symlink())
+        ok_(clone1_annex.resolve().samefile(origin.repo.dot_git / 'annex'))
+        if not clone1.repo.is_managed_branch():
+            # TODO: We can't properly handle adjusted branch yet
+            eq_((clone1.pathobj / file_test).read_text(), 'some')
+            eq_((clone1.pathobj / file_testsub).read_text(), 'somemore')
+
+    # 2. clone via file-scheme URL
+    clone2 = clone('file://' + Path(origin_path).as_posix(), clone2_path,
+                   reckless='ephemeral')
+
+    if can_symlink:
+        clone2_annex = (clone2.repo.dot_git / 'annex')
+        ok_(clone2_annex.is_symlink())
+        ok_(clone2_annex.resolve().samefile(origin.repo.dot_git / 'annex'))
+        if not clone2.repo.is_managed_branch():
+            # TODO: We can't properly handle adjusted branch yet
+            eq_((clone1.pathobj / file_test).read_text(), 'some')
+            eq_((clone1.pathobj / file_testsub).read_text(), 'somemore')
+
+    # 3. add something to clone1 and push back to origin availability from
+    # clone1 should not be propagated (we declared 'here' dead to that end)
+
+    (clone1.pathobj / 'addition.txt').write_text("even more")
+    clone1.save()
+    origin.config.set("receive.denyCurrentBranch", "updateInstead",
+                      where="local")
+    # Note, that the only thing to test is git-annex-dead here,
+    # if we couldn't symlink:
+    clone1.publish(to='origin', transfer_data='none' if can_symlink else 'auto')
+    if not origin.repo.is_managed_branch():
+        # test logic cannot handle adjusted branches
+        eq_(origin.repo.get_hexsha(), clone1.repo.get_hexsha())
+    res = origin.repo.whereis("addition.txt")
+    if can_symlink:
+        # obv. present in origin, but this is not yet known to origin:
+        eq_(res, [])
+        res = origin.repo.fsck()
+        assert_result_count(res, 3, success=True)
+        # TODO: Double check whether annex reports POSIX paths o windows!
+        eq_({str(file_test), str(file_testsub), "addition.txt"},
+            {r['file'] for r in res})
+        # now origin knows:
+    res = origin.repo.whereis("addition.txt")
+    eq_(res, [origin.config.get("annex.uuid")])
+
+
 @with_tempfile(mkdir=True)
 def test_clone_unborn_head(path):
     ds_origin = Dataset(op.join(path, "a")).create()
@@ -778,7 +1087,7 @@ def test_clone_unborn_head(path):
     # The setup below is involved, mostly because it's accounting for adjusted
     # branches. The scenario itself isn't so complicated, though:
     #
-    #   * a checked out master branch with no commits
+    #   * a checked out default branch with no commits
     #   * a (potentially adjusted) "abc" branch with commits.
     #   * a (potentially adjusted) "chooseme" branch whose tip commit has a
     #     more recent commit than any in "abc".
@@ -786,22 +1095,25 @@ def test_clone_unborn_head(path):
     ds_origin.save(message="foo")
     for res in repo.for_each_ref_(fields="refname"):
         ref = res["refname"]
-        if "master" in ref:
-            repo.update_ref(ref.replace("master", "abc"), ref)
+        if DEFAULT_BRANCH in ref:
+            repo.update_ref(ref.replace(DEFAULT_BRANCH, "abc"), ref)
             repo.call_git(["update-ref", "-d", ref])
     repo.update_ref("HEAD",
                     "refs/heads/{}".format(
                         "adjusted/abc(unlocked)" if managed else "abc"),
                     symbolic=True)
+    abc_ts = int(repo.format_commit("%ct"))
     repo.call_git(["checkout", "-b", "chooseme", "abc~1"])
     if managed:
         repo.adjust()
     (ds_origin.pathobj / "bar").write_text("bar content")
-    ds_origin.save(message="bar")
-    # Try to make the git-annex branch the most recently updated ref so that we
-    # test that it is skipped.
-    ds_origin.drop("bar", check=False)
-    ds_origin.repo.checkout("master", options=["--orphan"])
+    with set_date(abc_ts + 1):
+        ds_origin.save(message="bar")
+    # Make the git-annex branch the most recently updated ref so that we test
+    # that it is skipped.
+    with set_date(abc_ts + 2):
+        ds_origin.drop("bar", check=False)
+    ds_origin.repo.checkout(DEFAULT_BRANCH, options=["--orphan"])
 
     ds = clone(ds_origin.path, op.join(path, "b"))
     # We landed on the branch with the most recent commit, ignoring the
@@ -818,9 +1130,9 @@ def test_clone_unborn_head(path):
 
 @with_tempfile(mkdir=True)
 def test_clone_unborn_head_no_other_ref(path):
-    # TODO: On master, update to use annex=False.
-    ds_origin = Dataset(op.join(path, "a")).create(no_annex=True)
-    ds_origin.repo.call_git(["update-ref", "-d", "refs/heads/master"])
+    ds_origin = Dataset(op.join(path, "a")).create(annex=False)
+    ds_origin.repo.call_git(["update-ref", "-d",
+                             "refs/heads/" + DEFAULT_BRANCH])
     with swallow_logs(new_level=logging.WARNING) as cml:
         clone(source=ds_origin.path, path=op.join(path, "b"))
         assert_in("could not find a branch with commits", cml.out)
@@ -831,9 +1143,29 @@ def test_clone_unborn_head_sub(path):
     ds_origin = Dataset(op.join(path, "a")).create()
     ds_origin_sub = Dataset(op.join(path, "a", "sub")).create()
     managed = ds_origin_sub.repo.is_managed_branch()
-    ds_origin_sub.repo.call_git(["branch", "-m", "master", "other"])
+    ds_origin.save(message="foo")
+    sub_repo = ds_origin_sub.repo
+    # As with test_clone_unborn_head(), the setup below is complicated mostly
+    # because it's accounting for adjusted branches, but the scenario itself
+    # isn't too complicated:
+    #
+    #   * a submodule's HEAD points to a checked out branch with no commits
+    #     while a (potentially adjusted) "other" branch has commits
+    #
+    #   * the parent repo has the tip of "other" as the last recorded state
+    for res in sub_repo.for_each_ref_(fields="refname"):
+        ref = res["refname"]
+        if DEFAULT_BRANCH in ref:
+            sub_repo.update_ref(ref.replace(DEFAULT_BRANCH, "other"), ref)
+            sub_repo.call_git(["update-ref", "-d", ref])
+    sub_repo.update_ref(
+        "HEAD",
+        "refs/heads/{}".format(
+            "adjusted/other(unlocked)" if managed else "other"),
+        symbolic=True)
+    # END complicated handling for adjusted branches
     ds_origin.save()
-    ds_origin_sub.repo.checkout("master", options=["--orphan"])
+    ds_origin_sub.repo.checkout(DEFAULT_BRANCH, options=["--orphan"])
 
     ds_cloned = clone(source=ds_origin.path, path=op.join(path, "b"))
     ds_cloned_sub = ds_cloned.get(
@@ -845,3 +1177,56 @@ def test_clone_unborn_head_sub(path):
     # In the context of this test, the clone should be on an adjusted branch if
     # the source landed there initially because we're on the same file system.
     eq_(managed, ds_cloned_sub.repo.is_managed_branch())
+
+
+@skip_if_no_network
+@with_tempfile
+def test_gin_cloning(path):
+    # can we clone a public ds anoynmously from gin and retrieve content
+    ds = clone('https://gin.g-node.org/datalad/datalad-ci-target', path)
+    ok_(ds.is_installed())
+    annex_path = op.join('annex', 'two')
+    git_path = op.join('git', 'one')
+    eq_(ds.repo.file_has_content(annex_path), False)
+    eq_(ds.repo.is_under_annex(git_path), False)
+    result = ds.get(annex_path)
+    assert_result_count(result, 1)
+    assert_status('ok', result)
+    eq_(result[0]['path'], op.join(ds.path, annex_path))
+    ok_file_has_content(op.join(ds.path, annex_path), 'two\n')
+    ok_file_has_content(op.join(ds.path, git_path), 'one\n')
+
+
+@with_tree(tree={"special": {"f0": "0"}})
+@serve_path_via_http
+@with_tempfile(mkdir=True)
+def test_fetch_git_special_remote(url_path, url, path):
+    url_path = Path(url_path)
+    path = Path(path)
+    ds_special = Dataset(url_path / "special").create(force=True)
+    if ds_special.repo.is_managed_branch():
+        # TODO: git-annex-init fails in the second clone call below when this is
+        # executed under ./tools/eval_under_testloopfs.
+        raise SkipTest("Test fails on managed branch")
+    ds_special.save()
+    ds_special.repo.call_git(["update-server-info"])
+
+    clone_url = url + "special/.git"
+    ds_a = clone(clone_url, path / "a")
+    ds_a.repo._run_annex_command(
+        "initremote",
+        annex_options=["special", "type=git", "autoenable=true",
+                       "location=" + clone_url])
+
+    # Set up a situation where a file is present only on the special remote,
+    # and its existence is known only to the special remote's git-annex branch.
+    (ds_special.pathobj / "f1").write_text("1")
+    ds_special.save()
+    ds_special.repo.call_git(["update-server-info"])
+
+    ds_a.repo.fetch("origin")
+    ds_a.repo.merge("origin/" + DEFAULT_BRANCH)
+
+    ds_b = clone(ds_a.path, path / "other")
+    ds_b.get("f1")
+    ok_(ds_b.repo.file_has_content("f1"))
