@@ -1,4 +1,3 @@
-
 # -*- coding: utf-8 -*-
 # ex: set sts=4 ts=4 sw=4 noet:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
@@ -25,6 +24,7 @@ from datalad.tests.utils import (
     assert_repo_status,
     assert_result_count,
     assert_status,
+    DEFAULT_BRANCH,
     eq_,
     neq_,
     ok_,
@@ -32,6 +32,7 @@ from datalad.tests.utils import (
     serve_path_via_http,
     skip_if_on_windows,
     skip_ssh,
+    slow,
     with_tempfile,
     with_tree,
     SkipTest,
@@ -46,6 +47,8 @@ from datalad.core.distributed.clone import Clone
 from datalad.core.distributed.push import Push
 from datalad.support.network import get_local_file_url
 
+DEFAULT_REFSPEC = "refs/heads/{0}:refs/heads/{0}".format(DEFAULT_BRANCH)
+
 
 @with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
@@ -75,6 +78,12 @@ def test_invalid_call(origin, tdir):
         ValueError,
         ds.push, to='target', since='09320957509720437523')
 
+    # If a publish() user accidentally passes since='', which push() spells as
+    # since='^', the call is aborted.
+    assert_raises(
+        ValueError,
+        ds.push, to='target', since='')
+
 
 def mk_push_target(ds, name, path, annex=True, bare=True):
     # life could be simple, but nothing is simple on windows
@@ -113,7 +122,7 @@ def check_push(annex, src_path, dst_path):
     src_repo = src.repo
     # push should not add branches to the local dataset
     orig_branches = src_repo.get_branches()
-    assert_not_in('synced/master', orig_branches)
+    assert_not_in('synced/' + DEFAULT_BRANCH, orig_branches)
 
     res = src.push(on_failure='ignore')
     assert_result_count(res, 1)
@@ -132,16 +141,18 @@ def check_push(annex, src_path, dst_path):
     assert_in_results(
         res,
         action='publish', status='ok', target='target',
-        refspec='refs/heads/master:refs/heads/master',
+        refspec=DEFAULT_REFSPEC,
         operations=['new-branch'])
 
     assert_repo_status(src_repo, annex=annex)
-    eq_(list(target.get_branch_commits_("master")),
-        list(src_repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(src_repo.get_branch_commits_(DEFAULT_BRANCH)))
 
     # configure a default merge/upstream target
-    src.config.set('branch.master.remote', 'target', where='local')
-    src.config.set('branch.master.merge', 'master', where='local')
+    src.config.set('branch.{}.remote'.format(DEFAULT_BRANCH),
+                   'target', where='local')
+    src.config.set('branch.{}.merge'.format(DEFAULT_BRANCH),
+                   DEFAULT_BRANCH, where='local')
 
     # don't fail when doing it again, no explicit target specification
     # needed anymore
@@ -151,8 +162,8 @@ def check_push(annex, src_path, dst_path):
     assert_status('notneeded', res)
 
     assert_repo_status(src_repo, annex=annex)
-    eq_(list(target.get_branch_commits_("master")),
-        list(src_repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(src_repo.get_branch_commits_(DEFAULT_BRANCH)))
 
     # some modification:
     (src.pathobj / 'test_mod_file').write_text("Some additional stuff.")
@@ -168,7 +179,7 @@ def check_push(annex, src_path, dst_path):
     assert_in_results(
         res,
         action='publish', status='ok', target='target',
-        refspec='refs/heads/master:refs/heads/master',
+        refspec=DEFAULT_REFSPEC,
         # we get to see what happened
         operations=['fast-forward'])
     if annex:
@@ -188,8 +199,8 @@ def check_push(annex, src_path, dst_path):
             src_repo.pathobj / 'test_mod_annex_file',
             'Heavy stuff.')
 
-    eq_(list(target.get_branch_commits_("master")),
-        list(src_repo.get_branch_commits_("master")))
+    eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+        list(src_repo.get_branch_commits_(DEFAULT_BRANCH)))
     if not (annex and src_repo.is_managed_branch()):
         # the following doesn't make sense in managed branches, because
         # a commit that could be amended is no longer the last commit
@@ -201,24 +212,23 @@ def check_push(annex, src_path, dst_path):
         # push should be rejected (non-fast-forward):
         res = src.push(to='target', since='HEAD~2', on_failure='ignore')
         # fails before even touching the annex branch
-        assert_result_count(res, 1)
         assert_in_results(
             res,
             action='publish', status='error', target='target',
-            refspec='refs/heads/master:refs/heads/master',
+            refspec=DEFAULT_REFSPEC,
             operations=['rejected', 'error'])
         # push with force=True works:
         res = src.push(to='target', since='HEAD~2', force='gitpush')
         assert_in_results(
             res,
             action='publish', status='ok', target='target',
-            refspec='refs/heads/master:refs/heads/master',
+            refspec=DEFAULT_REFSPEC,
             operations=['forced-update'])
-        eq_(list(target.get_branch_commits_("master")),
-            list(src_repo.get_branch_commits_("master")))
+        eq_(list(target.get_branch_commits_(DEFAULT_BRANCH)),
+            list(src_repo.get_branch_commits_(DEFAULT_BRANCH)))
 
     # we do not have more branches than we had in the beginning
-    # in particular no 'synced/master'
+    # in particular no 'synced/<default branch>'
     eq_(orig_branches, src_repo.get_branches())
 
 
@@ -227,6 +237,7 @@ def test_push():
     yield check_push, True
 
 
+@slow  # 33sec on Yarik's laptop
 @with_tempfile
 @with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
@@ -254,7 +265,7 @@ def test_push_recursive(
     res = top.push(to="target", recursive=True, on_failure='ignore')
     assert_in_results(
         res, path=top.path, type='dataset',
-        refspec='refs/heads/master:refs/heads/master',
+        refspec=DEFAULT_REFSPEC,
         operations=['new-branch'], action='publish', status='ok',
         target='target')
     for d in (sub, subsub, subnoannex):
@@ -278,23 +289,23 @@ def test_push_recursive(
     for d in (sub, subsub, subnoannex):
         assert_in_results(
             res, status='ok', type='dataset', path=d.path,
-            refspec='refs/heads/master:refs/heads/master')
+            refspec=DEFAULT_REFSPEC)
     # all correspondig branches match across all datasets
     for s, d in zip((top, sub, subnoannex, subsub),
                     (target_top, target_sub, target_subnoannex,
                      target_subsub)):
-        eq_(list(s.repo.get_branch_commits_("master")),
-            list(d.get_branch_commits_("master")))
+        eq_(list(s.repo.get_branch_commits_(DEFAULT_BRANCH)),
+            list(d.get_branch_commits_(DEFAULT_BRANCH)))
         if s != subnoannex:
             eq_(list(s.repo.get_branch_commits_("git-annex")),
                 list(d.get_branch_commits_("git-annex")))
 
-    # rerun should not result in further pushes of master
+    # rerun should not result in further pushes of the default branch
     res = top.push(to="target", recursive=True)
     assert_not_in_results(
-        res, status='ok', refspec="refs/heads/master:refs/heads/master")
+        res, status='ok', refspec=DEFAULT_REFSPEC)
     assert_in_results(
-        res, status='notneeded', refspec="refs/heads/master:refs/heads/master")
+        res, status='notneeded', refspec=DEFAULT_REFSPEC)
 
     if top.repo.is_managed_branch():
         raise SkipTest(
@@ -315,7 +326,7 @@ def test_push_recursive(
     for d in (top, sub, subsub):
         assert_in_results(
             res, status='ok', type='dataset', path=d.path,
-            refspec='refs/heads/master:refs/heads/master')
+            refspec=DEFAULT_REFSPEC)
     # file content copied too
     assert_in_results(
         res,
@@ -342,7 +353,7 @@ def test_push_recursive(
     for d in (top, subnoannex):
         assert_in_results(
             res, status='ok', type='dataset', path=d.path,
-            refspec='refs/heads/master:refs/heads/master')
+            refspec=DEFAULT_REFSPEC)
     # an unconditional push should now pick up the remaining changes
     res = top.push(to="target", recursive=True)
     assert_in_results(
@@ -352,13 +363,14 @@ def test_push_recursive(
         path=str(sub.pathobj / 'test_mod_annex_file'))
     assert_in_results(
         res, status='ok', type='dataset', path=sub.path,
-        refspec='refs/heads/master:refs/heads/master')
+        refspec=DEFAULT_REFSPEC)
     for d in (top, subnoannex, subsub):
         assert_in_results(
             res, status='notneeded', type='dataset', path=d.path,
-            refspec='refs/heads/master:refs/heads/master')
+            refspec=DEFAULT_REFSPEC)
 
 
+@slow  # 12sec on Yarik's laptop
 @with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
@@ -405,7 +417,7 @@ def test_force_checkdatapresent(srcpath, dstpath):
     # nothing reported to be copied
     assert_not_in_results(res, action='copy')
     # we got the git-push nevertheless
-    eq_(src.repo.get_hexsha('master'), target.get_hexsha('master'))
+    eq_(src.repo.get_hexsha(DEFAULT_BRANCH), target.get_hexsha(DEFAULT_BRANCH))
     # nothing moved
     eq_(whereis_prior, src.repo.whereis(files=['test_mod_annex_file'])[0])
 
@@ -415,7 +427,7 @@ def test_force_checkdatapresent(srcpath, dstpath):
     res = src.push(to='target', force=None)
     # no branch change, done before
     assert_in_results(res, action='publish', status='notneeded',
-                      refspec='refs/heads/master:refs/heads/master')
+                      refspec=DEFAULT_REFSPEC)
     # but availability update
     assert_in_results(res, action='publish', status='ok',
                       refspec='refs/heads/git-annex:refs/heads/git-annex')
@@ -436,7 +448,7 @@ def test_force_checkdatapresent(srcpath, dstpath):
     res = src.push(to='target', force='checkdatapresent')
     # no branch change, done before
     assert_in_results(res, action='publish', status='notneeded',
-                      refspec='refs/heads/master:refs/heads/master')
+                      refspec=DEFAULT_REFSPEC)
     # no availability update
     assert_in_results(res, action='publish', status='notneeded',
                       refspec='refs/heads/git-annex:refs/heads/git-annex')
@@ -472,7 +484,7 @@ def test_ria_push(srcpath, dstpath):
     res = src.push(to='datastore')
     assert_in_results(
         res, action='publish', target='datastore', status='ok',
-        refspec='refs/heads/master:refs/heads/master')
+        refspec=DEFAULT_REFSPEC)
     assert_in_results(
         res, action='publish', target='datastore', status='ok',
         refspec='refs/heads/git-annex:refs/heads/git-annex')
@@ -491,19 +503,22 @@ def test_gh1426(origin_path, target_path):
     origin.push(to='target')
     assert_repo_status(origin.path)
     assert_repo_status(target.path)
-    eq_(origin.repo.get_hexsha('master'), target.get_hexsha('master'))
+    eq_(origin.repo.get_hexsha(DEFAULT_BRANCH),
+        target.get_hexsha(DEFAULT_BRANCH))
 
     # gist of #1426 is that a newly added subdataset does not cause the
     # superdataset to get published
     origin.create('sub')
     assert_repo_status(origin.path)
-    neq_(origin.repo.get_hexsha('master'), target.get_hexsha('master'))
+    neq_(origin.repo.get_hexsha(DEFAULT_BRANCH),
+         target.get_hexsha(DEFAULT_BRANCH))
     # now push
     res = origin.push(to='target')
     assert_result_count(
         res, 1, status='ok', type='dataset', path=origin.path,
         action='publish', target='target', operations=['fast-forward'])
-    eq_(origin.repo.get_hexsha('master'), target.get_hexsha('master'))
+    eq_(origin.repo.get_hexsha(DEFAULT_BRANCH),
+        target.get_hexsha(DEFAULT_BRANCH))
 
 
 @skip_if_on_windows  # create_sibling incompatible with win servers
@@ -518,7 +533,7 @@ def test_publish_target_url(src, desttop, desturl):
         raise SkipTest(
             'Skipped due to https://github.com/datalad/datalad/issues/4075')
     ds.save('1')
-    ds.create_sibling('ssh://localhost:%s/subdir' % desttop,
+    ds.create_sibling('ssh://datalad-test:%s/subdir' % desttop,
                       name='target',
                       target_url=desturl + 'subdir/.git')
     results = ds.push(to='target')
@@ -631,6 +646,7 @@ def test_push_wanted(srcpath, dstpath):
     eq_((dst.pathobj / 'secure.1').read_text(), '1')
 
 
+@slow  # 10sec on Yarik's laptop
 @with_tempfile(mkdir=True)
 def test_auto_data_transfer(path):
     path = Path(path)
@@ -691,6 +707,7 @@ def test_auto_data_transfer(path):
         path=str(ds_a.pathobj / "bar.dat"))
 
 
+@slow  # 16sec on Yarik's laptop
 @with_tempfile(mkdir=True)
 def test_auto_if_wanted_data_transfer_path_restriction(path):
     path = Path(path)
@@ -760,3 +777,17 @@ def test_auto_if_wanted_data_transfer_path_restriction(path):
         res,
         action="copy", target="b", status="ok",
         path=str(ds_a.pathobj / "sec.dat"))
+
+
+@with_tempfile(mkdir=True)
+def test_push_git_annex_branch_when_no_data(path):
+    path = Path(path)
+    ds = Dataset(path / "a").create()
+    target = mk_push_target(ds, "target", str(path / "target"),
+                            annex=False, bare=True)
+    (ds.pathobj / "f0").write_text("0")
+    ds.save()
+    ds.push(to="target", data="nothing")
+    assert_in("git-annex",
+              {d["refname:strip=2"]
+               for d in target.for_each_ref_(fields="refname:strip=2")})
