@@ -19,28 +19,30 @@ from datalad.distribution.dataset import (
 )
 from datalad.api import create
 from datalad.support.exceptions import CommandError
+from datalad.support.annexrepo import AnnexRepo
 from datalad.utils import (
     chpwd,
-    Path,
     on_windows,
+    Path,
 )
 from datalad.cmd import Runner
 
 from datalad.tests.utils import (
-    with_tempfile,
-    eq_,
-    ok_,
-    assert_not_in,
     assert_in,
-    assert_status,
-    assert_raises,
     assert_in_results,
-    swallow_outputs,
-    with_tree,
+    assert_not_in,
+    assert_raises,
+    assert_repo_status,
+    assert_status,
+    eq_,
+    has_symlink_capability,
     OBSCURE_FILENAME,
+    ok_,
+    swallow_outputs,
+    with_tempfile,
+    with_tree,
 )
 
-from datalad.tests.utils import assert_repo_status
 
 
 _dataset_hierarchy_template = {
@@ -61,7 +63,7 @@ raw = dict(return_type='list', result_filter=None, result_xfm=None, on_failure='
 def test_create_raises(path, outside_path):
     ds = Dataset(path)
     # incompatible arguments (annex only):
-    assert_raises(ValueError, ds.create, no_annex=True, description='some')
+    assert_raises(ValueError, ds.create, annex=False, description='some')
 
     with open(op.join(path, "somefile.tst"), 'w') as f:
         f.write("some")
@@ -153,7 +155,7 @@ def test_create_curdir(path, path2):
     assert_repo_status(ds.path, annex=True)
 
     with chpwd(path2, mkdir=True):
-        create(no_annex=True)
+        create(annex=False)
     ds = Dataset(path2)
     ok_(ds.is_installed())
     assert_repo_status(ds.path, annex=False)
@@ -161,18 +163,23 @@ def test_create_curdir(path, path2):
 
 
 @with_tempfile
-def test_create(path):
+@with_tempfile
+def test_create(probe, path):
+    # only as a probe whether this FS is a crippled one
+    ar = AnnexRepo(probe, create=True)
+
     ds = Dataset(path)
     ds.create(
         description="funny",
         # custom git init option
-        initopts=dict(shared='world'))
+        initopts=dict(shared='world') if not ar.is_managed_branch() else None)
     ok_(ds.is_installed())
     assert_repo_status(ds.path, annex=True)
 
     # check default backend
     eq_(ds.config.get("annex.backends"), 'MD5E')
-    eq_(ds.config.get("core.sharedrepository"), '2')
+    if not ar.is_managed_branch():
+        eq_(ds.config.get("core.sharedrepository"), '2')
     runner = Runner()
     # check description in `info`
     cmd = ['git', 'annex', 'info']
@@ -220,7 +227,7 @@ def test_create_sub(path):
     assert_not_in("someother", ds.subdatasets(result_xfm='relpaths'))
 
     # 3. create sub via super:
-    subds3 = ds.create("third", no_annex=True)
+    subds3 = ds.create("third", annex=False)
     ok_(isinstance(subds3, Dataset))
     ok_(subds3.is_installed())
     assert_repo_status(subds3.path, annex=False)
@@ -493,7 +500,7 @@ def test_create_relpath_semantics():
 @with_tempfile(mkdir=True)
 @with_tempfile()
 def test_gh2927(path, linkpath):
-    if not on_windows:
+    if has_symlink_capability():
         # make it more complicated by default
         Path(linkpath).symlink_to(path, target_is_directory=True)
         path = linkpath
