@@ -22,9 +22,10 @@ from datalad.tests.utils import (
     assert_status,
     assert_true,
     has_symlink_capability,
-    known_failure_windows,
-    skip_ssh,
     SkipTest,
+    known_failure_windows,
+    skip_if_no_network,
+    skip_ssh,
     slow,
     swallow_logs,
     turtle,
@@ -281,6 +282,7 @@ def _test_remote_layout(host, dspath, store, archiv_store):
         assert_equal(len(ds.repo.whereis('one.txt')), len(whereis) + 1)
 
 
+@slow  # 12sec + ? on travis
 def test_remote_layout():
     # TODO: Skipped due to gh-4436
     yield known_failure_windows(skip_ssh(_test_remote_layout)), 'datalad-test'
@@ -372,6 +374,7 @@ def _test_version_check(host, dspath, store):
     ds.repo.copy_to('new_file', 'store')
 
 
+@slow  # 17sec + ? on travis
 def test_version_check():
     # TODO: Skipped due to gh-4436
     yield known_failure_windows(skip_ssh(_test_version_check)), 'datalad-test'
@@ -422,6 +425,13 @@ def _test_gitannex(host, store, dspath):
     init_opts = common_init_opts + ['url={}'.format(store_url)]
     ds.repo.init_remote('store', options=init_opts)
 
+    from datalad.support.external_versions import external_versions
+    if '8.20200330' < external_versions['cmd:annex'] < '8.20200624':
+        # https://git-annex.branchable.com/bugs/testremote_breeds_way_too_many_instances_of_the_externals_remote/?updated
+        raise SkipTest(
+            "git-annex might lead to overwhelming number of external "
+            "special remote instances")
+
     # run git-annex-testremote
     # note, that we don't want to capture output. If something goes wrong we
     # want to see it in test build's output log.
@@ -437,6 +447,7 @@ def test_gitannex_ssh():
     _test_gitannex('datalad-test')
 
 
+@slow  # 41sec on travis
 def test_gitannex_local():
     _test_gitannex(None)
 
@@ -497,4 +508,4 @@ def _test_binary_data(host, store, dspath):
 def test_binary_data():
     # TODO: Skipped due to gh-4436
     yield known_failure_windows(skip_ssh(_test_binary_data)), 'datalad-test'
-    yield _test_binary_data, None
+    yield skip_if_no_network(_test_binary_data), None
