@@ -19,7 +19,11 @@ import requests.auth
 import io
 from time import sleep
 
-from ..utils import assure_list_from_str, assure_dict_from_str
+from ..utils import (
+    assure_list_from_str,
+    assure_dict_from_str,
+    ensure_bytes,
+)
 from ..dochelpers import borrowkwargs
 
 from ..ui import ui
@@ -46,10 +50,11 @@ lgr = getLogger('datalad.http')
 
 try:
     import requests_ftp
+    _FTP_SUPPORT = True
     requests_ftp.monkeypatch_session()
 except ImportError as e:
     lgr.debug("Failed to import requests_ftp, thus no ftp support: %s" % exc_str(e))
-    pass
+    _FTP_SUPPORT = False
 
 if lgr.getEffectiveLevel() <= 1:
     # Let's also enable requests etc debugging
@@ -208,8 +213,11 @@ class HTTPBaseAuthenticator(Authenticator):
 
     def check_for_auth_failure(self, content, err_prefix=""):
         if self.failure_re:
+            content_is_bytes = isinstance(content, bytes)
             # verify that we actually logged in
             for failure_re in self.failure_re:
+                if content_is_bytes:
+                    failure_re = ensure_bytes(failure_re)
                 if re.search(failure_re, content):
                     raise AccessDeniedError(
                         err_prefix + "returned output which matches regular expression %s" % failure_re
@@ -500,10 +508,15 @@ class HTTPDownloader(BaseDownloader):
                 # so let's rest and try again
                 if retry >= nretries:
                     #import epdb; epdb.serve()
+                    if not _FTP_SUPPORT and url.startswith("ftp://"):
+                        msg_ftp = "For ftp:// support, install requests_ftp. "
+                    else:
+                        msg_ftp = ""
+
                     raise AccessFailedError(
-                        "Failed to establish a new session %d times. "
+                        "Failed to establish a new session %d times. %s"
                         "Last exception was: %s"
-                        % (nretries, exc_str(exc)))
+                        % (nretries, msg_ftp, exc_str(exc)))
                 lgr.warning(
                     "Caught exception %s. Will retry %d out of %d times",
                     exc_str(exc), retry+1, nretries)
