@@ -9,18 +9,24 @@
 """Tests for credentials"""
 
 from unittest.mock import patch
-
-from datalad.tests.utils import with_testsui
-from datalad.tests.utils import assert_equal
-from datalad.tests.utils import assert_in
-from datalad.tests.utils import assert_true, assert_false
-from datalad.tests.utils import assert_raises
-from datalad.tests.utils import SkipTest
-from datalad.support.keyring_ import MemoryKeyring
-from datalad.support.keyring_ import Keyring
-from ..credentials import UserPassword
-from ..credentials import CompositeCredential
-from ..credentials import AWS_S3
+from datalad.tests.utils import (
+    assert_equal,
+    assert_false,
+    assert_in,
+    assert_raises,
+    assert_true,
+    SkipTest,
+    with_testsui,
+)
+from datalad.support.keyring_ import (
+    Keyring,
+    MemoryKeyring,
+)
+from ..credentials import (
+    AWS_S3,
+    CompositeCredential,
+    UserPassword,
+)
 
 
 @with_testsui(responses=[
@@ -126,4 +132,4 @@ def test_credentials_from_env():
             assert_equal(cred.get('key_id'), '1')
             assert_equal(cred.get('secret_id'), '2')
             assert_true(cred.is_known)
-        assert_false(cred.is_known)  # no memory of the past
\ No newline at end of file
+        assert_false(cred.is_known)  # no memory of the past
