@@ -13,11 +13,14 @@
 __docformat__ = 'restructuredtext'
 
 from appdirs import AppDirs
+from os import environ
 from os.path import join as opj, expanduser
 from datalad.support.constraints import EnsureBool
 from datalad.support.constraints import EnsureInt
 from datalad.support.constraints import EnsureNone
 from datalad.support.constraints import EnsureChoice
+from datalad.support.constraints import EnsureListOf
+from datalad.support.constraints import EnsureStr
 
 dirs = AppDirs("datalad", "datalad.org")
 
@@ -159,9 +162,17 @@ definitions = {
         'type': EnsureBool(),
         'default': False,
     },
+    'datalad.tests.setup.testrepos': {
+        'ui': ('question', {
+            'title': 'Pre-creates repositories for @with_testrepos within setup_package'}),
+        'type': EnsureBool(),
+        'default': False,
+    },
     'datalad.tests.temp.dir': {
         'ui': ('question', {
                'title': 'Create a temporary directory at location specified by this flag. It is used by tests to create a temporary git directory while testing git annex archives etc'}),
+        'type': EnsureStr(),
+        'default': environ.get('TMPDIR'),
     },
     'datalad.tests.temp.keep': {
         'ui': ('yesno', {
