@@ -16,18 +16,20 @@ from os.path import join as opj
 from datalad.api import metadata
 from datalad.distribution.dataset import Dataset
 
-
-from datalad.tests.utils import skip_ssh
-from datalad.tests.utils import with_tree
-from datalad.tests.utils import with_tempfile
-from datalad.tests.utils import assert_result_count
-from datalad.tests.utils import assert_status
-from datalad.tests.utils import assert_dict_equal
-from datalad.tests.utils import assert_not_in
-from datalad.tests.utils import eq_
-from datalad.tests.utils import ok_clean_git
-from datalad.tests.utils import skip_if_on_windows
-from datalad.tests.utils import known_failure_githubci_win
+from datalad.tests.utils import (
+    assert_dict_equal,
+    assert_not_in,
+    assert_repo_status,
+    assert_result_count,
+    assert_status,
+    eq_,
+    known_failure_githubci_win,
+    skip_if_on_windows,
+    skip_ssh,
+    slow,
+    with_tempfile,
+    with_tree,
+)
 
 
 def _assert_metadata_empty(meta):
@@ -57,6 +59,7 @@ _dataset_hierarchy_template = {
 
 # underlying code cannot deal with adjusted branches
 # https://github.com/datalad/datalad/pull/3817
+@slow  # 20sec on Yarik's laptop
 @known_failure_githubci_win
 @with_tree(tree=_dataset_hierarchy_template)
 def test_basic_aggregate(path):
@@ -66,14 +69,14 @@ def test_basic_aggregate(path):
     #base.metadata(sub.path, init=dict(homepage='this'), apply2global=True)
     subsub = base.create(opj('sub', 'subsub'), force=True)
     base.save(recursive=True)
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     # we will first aggregate the middle dataset on its own, this will
     # serve as a smoke test for the reuse of metadata objects later on
     sub.aggregate_metadata()
     base.save()
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     base.aggregate_metadata(recursive=True, update_mode='all')
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     direct_meta = base.metadata(recursive=True, return_type='list')
     # loose the deepest dataset
     sub.uninstall('subsub', check=False)
@@ -88,7 +91,7 @@ def test_basic_aggregate(path):
     # no we can throw away the subdataset tree, and loose no metadata
     base.uninstall('sub', recursive=True, check=False)
     assert(not sub.is_installed())
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     # same result for aggregate query than for (saved) direct query
     agg_meta = base.metadata(recursive=True, return_type='list')
     for d, a in zip(direct_meta, agg_meta):
@@ -148,6 +151,7 @@ def test_aggregate_query(path):
 
 
 # this is for gh-1971
+@slow  # 23sec on Yarik's laptop
 @known_failure_githubci_win
 @with_tree(tree=_dataset_hierarchy_template)
 def test_reaggregate_with_unavailable_objects(path):
@@ -159,9 +163,9 @@ def test_reaggregate_with_unavailable_objects(path):
     sub = base.create('sub', force=True)
     subsub = base.create(opj('sub', 'subsub'), force=True)
     base.save(recursive=True)
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     base.aggregate_metadata(recursive=True, update_mode='all')
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     objpath = opj('.datalad', 'metadata', 'objects')
     objs = list(sorted(base.repo.find(objpath)))
     # we have 3x2 metadata sets (dataset/files) under annex
@@ -170,7 +174,7 @@ def test_reaggregate_with_unavailable_objects(path):
     # drop all object content
     base.drop(objs, check=False)
     eq_(all(base.repo.file_has_content(objs)), False)
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     # now re-aggregate, the state hasn't changed, so the file names will
     # be the same
     base.aggregate_metadata(recursive=True, update_mode='all', force_extraction=True)
@@ -182,6 +186,7 @@ def test_reaggregate_with_unavailable_objects(path):
     )
 
 
+@slow  # 26sec on Yarik's laptop
 @known_failure_githubci_win
 @with_tree(tree=_dataset_hierarchy_template)
 @with_tempfile(mkdir=True)
@@ -194,17 +199,17 @@ def test_aggregate_with_unavailable_objects_from_subds(path, target):
     sub = base.create('sub', force=True)
     subsub = base.create(opj('sub', 'subsub'), force=True)
     base.save(recursive=True)
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     base.aggregate_metadata(recursive=True, update_mode='all')
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
 
     # now make that a subdataset of a new one, so aggregation needs to get the
     # metadata objects first:
     super = Dataset(target).create()
     super.install("base", source=base.path)
-    ok_clean_git(super.path)
+    assert_repo_status(super.path)
     clone = Dataset(opj(super.path, "base"))
-    ok_clean_git(clone.path)
+    assert_repo_status(clone.path)
     objpath = opj('.datalad', 'metadata', 'objects')
     objs = [o for o in sorted(clone.repo.get_annexed_files(with_content_only=False)) if o.startswith(objpath)]
     eq_(len(objs), 6)
@@ -217,6 +222,7 @@ def test_aggregate_with_unavailable_objects_from_subds(path, target):
 
 
 # this is for gh-1987
+@slow  # 23sec on Yarik's laptop
 @skip_if_on_windows  # create_sibling incompatible with win servers
 @skip_ssh
 @with_tree(tree=_dataset_hierarchy_template)
@@ -228,15 +234,18 @@ def test_publish_aggregated(path):
             '** annex.largefiles=nothing\nmetadata/objects/** annex.largefiles=anything\n')
     base.create('sub', force=True)
     base.save(recursive=True)
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     base.aggregate_metadata(recursive=True, update_mode='all')
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
 
     # create sibling and publish to it
-    spath = opj(path, 'remote')
+    # Note: Use realpath() below because we know that the resolved temporary
+    # test directory exists in the target (many tests rely on that), but it
+    # doesn't necessarily have the unresolved variant.
+    spath = op.realpath(opj(path, 'remote'))
     base.create_sibling(
         name="local_target",
-        sshurl="ssh://localhost",
+        sshurl="ssh://datalad-test",
         target_dir=spath)
     base.publish('.', to='local_target', transfer_data='all')
     remote = Dataset(spath)
@@ -277,7 +286,7 @@ def test_aggregate_removal(path):
     subsub = sub.create(opj('subsub'), force=True)
     base.save(recursive=True)
     base.aggregate_metadata(recursive=True, update_mode='all')
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     res = base.metadata(get_aggregates=True)
     assert_result_count(res, 3)
     assert_result_count(res, 1, path=subsub.path)
@@ -289,7 +298,7 @@ def test_aggregate_removal(path):
     # now aggregation has to detect that subsub is not simply missing, but gone
     # for good
     base.aggregate_metadata(recursive=True, update_mode='all')
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     # internally consistent state
     eq_(_get_contained_objs(base), _get_referenced_objs(base))
     # info on subsub was removed at all levels
@@ -303,6 +312,7 @@ def test_aggregate_removal(path):
 
 # underlying code cannot deal with adjusted branches
 # https://github.com/datalad/datalad/pull/3817
+@slow  # 22sec on Yarik's laptop
 @known_failure_githubci_win
 @with_tree(tree=_dataset_hierarchy_template)
 def test_update_strategy(path):
@@ -314,7 +324,7 @@ def test_update_strategy(path):
     sub = base.create('sub', force=True)
     subsub = sub.create(opj('subsub'), force=True)
     base.save(recursive=True)
-    ok_clean_git(base.path)
+    assert_repo_status(base.path)
     # we start clean
     for ds in base, sub, subsub:
         eq_(len(_get_contained_objs(ds)), 0)
@@ -359,6 +369,7 @@ def test_update_strategy(path):
     eq_(target_meta, base.metadata(return_type='list'))
 
 
+@slow  # 14sec on Yarik's laptop
 @known_failure_githubci_win  # fails since upgrade to 8.20200226-g2d3ef2c07
 @with_tree({
     'this': 'that',
@@ -403,7 +414,7 @@ def test_partial_aggregation(path):
     with open(opj(sub1.path, 'here'), 'w') as f:
         f.write('fresh')
     ds.save(recursive=True)
-    ok_clean_git(path)
+    assert_repo_status(path)
     # TODO for later
     # test --since with non-incremental
     #ds.aggregate_metadata(recursive=True, since='HEAD~1', incremental=False)
