@@ -22,6 +22,7 @@ import multiprocessing
 import logging
 import random
 import socket
+import textwrap
 import warnings
 from fnmatch import fnmatch
 import time
@@ -29,23 +30,48 @@ from difflib import unified_diff
 from contextlib import contextmanager
 from unittest.mock import patch
 
-from http.server import SimpleHTTPRequestHandler
-from http.server import HTTPServer
+from http.server import (
+    HTTPServer,
+    SimpleHTTPRequestHandler,
+)
 
 from functools import wraps
-from os.path import exists, realpath, join as opj, pardir, split as pathsplit, curdir
-from os.path import relpath
+from os.path import (
+    curdir,
+    exists,
+    join as opj,
+    relpath,
+    split as pathsplit,
+)
 
 from nose.plugins.attrib import attr
-from nose.tools import \
-    assert_equal, assert_not_equal, assert_raises, assert_greater, assert_true, assert_false, \
-    assert_in, assert_not_in, assert_in as in_, assert_is, \
-    raises, ok_, eq_, make_decorator
+from nose.tools import (
+    assert_equal,
+    assert_false,
+    assert_greater,
+    assert_greater_equal,
+    assert_in as in_,
+    assert_in,
+    assert_is,
+    assert_is_none,
+    assert_is_not,
+    assert_is_not_none,
+    assert_not_equal,
+    assert_not_in,
+    assert_not_is_instance,
+    assert_raises,
+    assert_true,
+    eq_,
+    make_decorator,
+    ok_,
+    raises,
+)
 
 from nose.tools import assert_set_equal
 from nose.tools import assert_is_instance
 from nose import SkipTest
 
+from datalad import cfg as dl_cfg
 import datalad.utils as ut
 # TODO this must go
 from ..utils import *
@@ -56,7 +82,11 @@ from datalad.utils import (
 
 from ..cmd import Runner
 from .. import utils
-from ..support.exceptions import CommandNotAvailableError
+from ..support.exceptions import (
+    CommandError,
+    CommandNotAvailableError,
+)
+from ..support.external_versions import external_versions
 from ..support.vcr_ import *
 from ..support.keyring_ import MemoryKeyring
 from ..support.network import RI
@@ -74,6 +104,12 @@ _TEMP_PATHS_CLONES = set()
 # Additional indicators
 on_travis = bool(os.environ.get('TRAVIS', False))
 
+if external_versions["cmd:git"] >= "2.28":
+    # The specific value here doesn't matter, but it should not be the default
+    # from any Git version to test that we work with custom values.
+    DEFAULT_BRANCH = "dl-test-branch"  # Set by setup_package().
+else:
+    DEFAULT_BRANCH = "master"
 
 # additional shortcuts
 neq_ = assert_not_equal
@@ -129,7 +165,7 @@ def skip_if_no_network(func=None):
     check_not_generatorfunction(func)
 
     def check_and_raise():
-        if os.environ.get('DATALAD_TESTS_NONETWORK'):
+        if dl_cfg.get('datalad.tests.nonetwork'):
             raise SkipTest("Skipping since no network settings")
 
     if func:
@@ -164,6 +200,29 @@ def skip_if_on_windows(func=None):
         check_and_raise()
 
 
+def skip_if_root(func=None):
+    """Skip test if uid == 0.
+
+    Note that on Windows (or anywhere else `os.geteuid` is not available) the
+    test is _not_ skipped.
+    """
+    check_not_generatorfunction(func)
+
+    def check_and_raise():
+        if hasattr(os, "geteuid") and os.geteuid() == 0:
+            raise SkipTest("Skipping: test assumptions fail under root")
+
+    if func:
+        @wraps(func)
+        @attr('skip_if_root')
+        def newfunc(*args, **kwargs):
+            check_and_raise()
+            return func(*args, **kwargs)
+        return newfunc
+    else:
+        check_and_raise()
+
+
 @optional_args
 def skip_if(func, cond=True, msg=None, method='raise'):
     """Skip test for specific condition
@@ -206,8 +265,7 @@ def skip_ssh(func):
     @wraps(func)
     @attr('skip_ssh')
     def newfunc(*args, **kwargs):
-        from datalad import cfg
-        test_ssh = cfg.get("datalad.tests.ssh", '')
+        test_ssh = dl_cfg.get("datalad.tests.ssh", '')
         if not test_ssh or test_ssh in ('0', 'false', 'no'):
             raise SkipTest("Run this test by setting DATALAD_TESTS_SSH")
         return func(*args, **kwargs)
@@ -223,10 +281,9 @@ def skip_v6_or_later(func, method='raise'):
     installed git-annex.
     """
 
-    from datalad import cfg
     from datalad.support.annexrepo import AnnexRepo
 
-    version = cfg.obtain("datalad.repo.version")
+    version = dl_cfg.obtain("datalad.repo.version")
     info = AnnexRepo.check_repository_versions()
 
     @skip_if(version >= 6 or 5 not in info["supported"],
@@ -243,7 +300,6 @@ def skip_v6_or_later(func, method='raise'):
 # Addition "checkers"
 #
 
-import git
 import os
 from datalad.support.gitrepo import GitRepo
 from datalad.support.annexrepo import AnnexRepo, FileNotInAnnexError
@@ -251,89 +307,22 @@ from datalad.distribution.dataset import Dataset
 from ..utils import chpwd, getpwd
 
 
-def ok_clean_git(path, annex=None, head_modified=[], index_modified=[],
-                 untracked=[], ignore_submodules=False):
-    """Verify that under given path there is a clean git repository
+def ok_clean_git(path, annex=None, index_modified=[], untracked=[]):
+    """Obsolete test helper. Use assert_repo_status() instead.
 
-    it exists, .git exists, nothing is uncommitted/dirty/staged
-
-    Note
-    ----
-    Parameters head_modified and index_modified currently work
-    in pure git or indirect mode annex only. If they are given, no
-    test of modification of known repo content is performed.
-
-    Parameters
-    ----------
-    path: str or Repo
-      in case of a str: path to the repository's base dir;
-      Note, that passing a Repo instance prevents detecting annex. This might be
-      useful in case of a non-initialized annex, a GitRepo is pointing to.
-    annex: bool or None
-      explicitly set to True or False to indicate, that an annex is (not)
-      expected; set to None to autodetect, whether there is an annex.
-      Default: None.
-    ignore_submodules: bool
-      if True, submodules are not inspected
+    Still maps a few common cases to the new helper, to ease transition
+    in extensions.
     """
-    # TODO: See 'Note' in docstring
-
-    if isinstance(path, AnnexRepo):
-        if annex is None:
-            annex = True
-        # if `annex` was set to False, but we find an annex => fail
-        assert_is(annex, True)
-        r = path
-    elif isinstance(path, GitRepo):
-        if annex is None:
-            annex = False
-        # explicitly given GitRepo instance doesn't make sense with 'annex' True
-        assert_is(annex, False)
-        r = path
-    else:
-        # 'path' is an actual path
-        try:
-            r = AnnexRepo(path, init=False, create=False)
-            if annex is None:
-                annex = True
-            # if `annex` was set to False, but we find an annex => fail
-            assert_is(annex, True)
-        except Exception:
-            # Instantiation failed => no annex
-            try:
-                r = GitRepo(path, init=False, create=False)
-            except Exception:
-                raise AssertionError("Couldn't find an annex or a git "
-                                     "repository at {}.".format(path))
-            if annex is None:
-                annex = False
-            # explicitly given GitRepo instance doesn't make sense with
-            # 'annex' True
-            assert_is(annex, False)
-
-    eq_(sorted(r.untracked_files), sorted(untracked))
-
-    repo = r.repo
-
-    if repo.index.entries.keys():
-        ok_(repo.head.is_valid())
-
-        if not head_modified and not index_modified:
-            # get string representations of diffs with index to ease
-            # troubleshooting
-            head_diffs = [str(d) for d in repo.index.diff(repo.head.commit)]
-            index_diffs = [str(d) for d in repo.index.diff(None)]
-            eq_(head_diffs, [])
-            eq_(index_diffs, [])
-        else:
-            # TODO: These names are confusing/non-descriptive.  REDO
-            if head_modified:
-                # we did ask for interrogating changes
-                head_modified_ = [d.a_path for d in repo.index.diff(repo.head.commit)]
-                eq_(sorted(head_modified_), sorted(head_modified))
-            if index_modified:
-                index_modified_ = [d.a_path for d in repo.index.diff(None)]
-                eq_(sorted(index_modified_), sorted(index_modified))
+    kwargs = {}
+    if index_modified:
+        kwargs['modified'] = index_modified
+    if untracked:
+        kwargs['untracked'] = untracked
+    assert_repo_status(
+        path,
+        annex=annex,
+        **kwargs,
+    )
 
 
 def ok_file_under_git(path, filename=None, annexed=False):
@@ -400,7 +389,9 @@ def _prep_file_under_git(path, filename):
     # path to the file within the repository
     # repo.path is a "realpath" so to get relpath working correctly
     # we need to realpath our path as well
-    path = op.realpath(path)  # intentional realpath to match GitRepo behavior
+    # do absolute() in addition to always get an absolute path
+    # even with non-existing paths on windows
+    path = str(Path(path).resolve().absolute())  # intentional realpath to match GitRepo behavior
     file_repo_dir = op.relpath(path, repo.path)
     file_repo_path = filename if file_repo_dir == curdir else opj(file_repo_dir, filename)
     return annex, file_repo_path, filename, path, repo
@@ -419,16 +410,16 @@ def ok_symlink(path):
 
 def ok_good_symlink(path):
     ok_symlink(path)
-    rpath = realpath(path)
-    ok_(exists(rpath),
+    rpath = Path(path).resolve()
+    ok_(rpath.exists(),
         msg="Path {} seems to be missing.  Symlink {} is broken".format(
                 rpath, path))
 
 
 def ok_broken_symlink(path):
     ok_symlink(path)
-    rpath = realpath(path)
-    assert_false(exists(rpath),
+    rpath = Path(path).resolve()
+    assert_false(rpath.exists(),
             msg="Path {} seems to be present.  Symlink {} is not broken".format(
                     rpath, path))
 
@@ -552,6 +543,10 @@ def with_tree(t, tree=None, archives_leading_dir=True, delete=True, **tkwargs):
 
     @wraps(t)
     def newfunc(*arg, **kw):
+        if 'dir' not in tkwargs.keys():
+            # if not specified otherwise, respect datalad.tests.temp.dir config
+            # as this is a test helper
+            tkwargs['dir'] = dl_cfg.get("datalad.tests.temp.dir")
         tkwargs_ = get_tempfile_kwargs(tkwargs, prefix="tree", wrapped=t)
         d = tempfile.mkdtemp(**tkwargs_)
         create_tree(d, tree, archives_leading_dir=archives_leading_dir)
@@ -728,6 +723,10 @@ def with_tempfile(t, **tkwargs):
 
     @wraps(t)
     def newfunc(*arg, **kw):
+        if 'dir' not in tkwargs.keys():
+            # if not specified otherwise, respect datalad.tests.temp.dir config
+            # as this is a test helper
+            tkwargs['dir'] = dl_cfg.get("datalad.tests.temp.dir")
         with make_tempfile(wrapped=t, **tkwargs) as filename:
             return t(*(arg + (filename,)), **kw)
 
@@ -749,8 +748,7 @@ def probe_known_failure(func):
     @wraps(func)
     @attr('probe_known_failure')
     def newfunc(*args, **kwargs):
-        from datalad import cfg
-        if cfg.obtain("datalad.tests.knownfailures.probe"):
+        if dl_cfg.obtain("datalad.tests.knownfailures.probe"):
             assert_raises(Exception, func, *args, **kwargs)  # marked as known failure
             # Note: Since assert_raises lacks a `msg` argument, a comment
             # in the same line is helpful to determine what's going on whenever
@@ -768,9 +766,8 @@ def skip_known_failure(func, method='raise'):
     Setting config datalad.tests.knownfailures.skip to a bool enables/disables
     skipping.
     """
-    from datalad import cfg
 
-    @skip_if(cond=cfg.obtain("datalad.tests.knownfailures.skip"),
+    @skip_if(cond=dl_cfg.obtain("datalad.tests.knownfailures.skip"),
              msg="Skip test known to fail",
              method=method)
     @wraps(func)
@@ -806,10 +803,9 @@ def known_failure_v6_or_later(func):
     installed git-annex.
     """
 
-    from datalad import cfg
     from datalad.support.annexrepo import AnnexRepo
 
-    version = cfg.obtain("datalad.repo.version")
+    version = dl_cfg.obtain("datalad.repo.version")
     info = AnnexRepo.check_repository_versions()
 
     if (version and version >= 6) or 5 not in info["supported"]:
@@ -912,34 +908,17 @@ def _get_resolved_flavors(flavors):
     if not isinstance(flavors_, list):
         flavors_ = [flavors_]
 
-    if os.environ.get('DATALAD_TESTS_NONETWORK'):
+    if dl_cfg.get('datalad.tests.nonetwork'):
         flavors_ = [x for x in flavors_ if not x.startswith('network')]
     return flavors_
 
-def _get_repo_url(path):
-    """Return ultimate URL for this repo"""
-
-    if path.startswith('http') or path.startswith('git'):
-        # We were given a URL, so let's just return it
-        return path
-
-    if not exists(opj(path, '.git')):
-        # do the dummiest check so we know it is not git.Repo's fault
-        raise AssertionError("Path %s does not point to a git repository "
-                             "-- missing .git" % path)
-    repo = git.Repo(path)
-    if len(repo.remotes) == 1:
-        remote = repo.remotes[0]
-    else:
-        remote = repo.remotes.origin
-    return remote.config_reader.get('url')
-
 
 def clone_url(url):
     # delay import of our code until needed for certain
     from ..cmd import Runner
     runner = Runner()
-    tdir = tempfile.mkdtemp(**get_tempfile_kwargs({}, prefix='clone_url'))
+    tdir = tempfile.mkdtemp(**get_tempfile_kwargs(
+        {'dir': dl_cfg.get("datalad.tests.temp.dir")}, prefix='clone_url'))
     _ = runner(["git", "clone", url, tdir], expect_stderr=True)
     if GitRepo(tdir).is_with_annex():
         AnnexRepo(tdir, init=True)
@@ -1059,13 +1038,13 @@ def with_testrepos(t, regex='.*', flavors='auto', skip=False, count=None):
         testrepos_uris = _get_testrepos_uris(regex, flavors_)
         # we should always have at least one repo to test on, unless explicitly only
         # network was requested by we are running without networked tests
-        if not (os.environ.get('DATALAD_TESTS_NONETWORK') and flavors == ['network']):
+        if not (dl_cfg.get('datalad.tests.nonetwork') and flavors == ['network']):
             assert(testrepos_uris)
         else:
             if not testrepos_uris:
                 raise SkipTest("No non-networked repos to test on")
 
-        fake_dates = os.environ.get("DATALAD_FAKE__DATES")
+        fake_dates = dl_cfg.get("datalad.fake-dates")
         ntested = 0
         for uri in testrepos_uris:
             if count and ntested >= count:
@@ -1108,6 +1087,15 @@ def with_sameas_remote(func, autoenabled=False):
     @with_tempfile(mkdir=True)
     @with_tempfile(mkdir=True)
     def newfunc(*args, **kwargs):
+        # With git-annex's 8.20200522-77-g1f2e2d15e, transferring from an rsync
+        # special remote hangs on Xenial. This is likely due to an interaction
+        # with an older rsync or openssh version. Use openssh as a rough
+        # indicator. See
+        # https://git-annex.branchable.com/bugs/Recent_hang_with_rsync_remote_with_older_systems___40__Xenial__44___Jessie__41__/
+        if external_versions['cmd:system-ssh'] < '7.4' and \
+           '8.20200522' < external_versions['cmd:annex'] < '8.20200720':
+            raise SkipTest("Test known to hang")
+
         sr_path, repo_path = args[-2:]
         fn_args = args[:-2]
         repo = AnnexRepo(repo_path)
@@ -1316,6 +1304,12 @@ def assert_message(message, results):
         assert_equal(m, message)
 
 
+def _format_res(x):
+    return textwrap.indent(
+        dumps(x, indent=1, default=str, sort_keys=True),
+        prefix="  ")
+
+
 def assert_result_count(results, n, **kwargs):
     """Verify specific number of results (matching criteria, if any)"""
     count = 0
@@ -1327,12 +1321,12 @@ def assert_result_count(results, n, **kwargs):
             count += 1
     if not n == count:
         raise AssertionError(
-            'Got {} instead of {} expected results matching {}. Inspected {} record(s):\n{}'.format(
+            'Got {} instead of {} expected results matching\n{}\nInspected {} record(s):\n{}'.format(
                 count,
                 n,
-                kwargs,
+                _format_res(kwargs),
                 len(results),
-                dumps(results, indent=1, default=lambda x: str(x))))
+                _format_res(results)))
 
 
 def assert_in_results(results, **kwargs):
@@ -1342,7 +1336,10 @@ def assert_in_results(results, **kwargs):
     for r in assure_list(results):
         if all(k in r and r[k] == v for k, v in kwargs.items()):
             found = True
-    assert found, "Found no desired result (%s) among %s" % (repr(kwargs), repr(results))
+    if not found:
+        raise AssertionError(
+            "Desired result\n{}\nnot found among\n{}"
+            .format(_format_res(kwargs), _format_res(results)))
 
 
 def assert_not_in_results(results, **kwargs):
@@ -1559,8 +1556,6 @@ def assert_repo_status(path, annex=None, untracked_mode='normal', **kwargs):
     Anything file/directory that is not explicitly indicated must have
     state 'clean', i.e. no modifications and recorded in Git.
 
-    This is an alternative to the traditional `ok_clean_git` helper.
-
     Parameters
     ----------
     path: str or Repo
@@ -1848,16 +1843,13 @@ def get_deeply_nested_structure(path):
     return ds
 
 
-def has_symlink_capability():
-    try:
-        wdir = ut.Path(tempfile.mkdtemp())
-        (wdir / 'target').touch()
-        (wdir / 'link').symlink_to(wdir / 'target')
-        return True
-    except Exception:
-        return False
-    finally:
-        shutil.rmtree(str(wdir))
+@with_tempfile
+@with_tempfile
+def has_symlink_capability(p1, p2):
+
+    path = ut.Path(p1)
+    target = ut.Path(p2)
+    return utils.check_symlink_capability(path, target)
 
 
 def skip_wo_symlink_capability(func):
@@ -1875,6 +1867,49 @@ def skip_wo_symlink_capability(func):
     return newfunc
 
 
+def get_ssh_port(host):
+    """Get port of `host` in ssh_config.
+
+    Our tests depend on the host being defined in ssh_config, including its
+    port. This method can be used by tests that want to check handling of an
+    explicitly specified
+
+    Note that if `host` does not match a host in ssh_config, the default value
+    of 22 is returned.
+
+    Parameters
+    ----------
+    host : str
+
+    Returns
+    -------
+    port (int)
+
+    Raises
+    ------
+    SkipTest if port cannot be found.
+    """
+    out = ''
+    try:
+        out, err = Runner()(["ssh", "-G", host])
+    except Exception as exc:
+        err = str(exc)
+
+    port = None
+    for line in out.splitlines():
+        if line.startswith("port "):
+            try:
+                port = int(line.split()[1])
+            except Exception as exc:
+                err = str(exc)
+            break
+
+    if port is None:
+        raise SkipTest("port for {} could not be determined: {}"
+                       .format(host, err))
+    return port
+
+
 #
 # Context Managers
 #
@@ -1883,8 +1918,7 @@ def skip_wo_symlink_capability(func):
 def patch_config(vars):
     """Patch our config with custom settings. Returns mock.patch cm
     """
-    from datalad import cfg
-    return patch.dict(cfg._store, vars)
+    return patch.dict(dl_cfg._store, vars)
 
 
 @contextmanager
@@ -1935,19 +1969,33 @@ from nose.plugins.attrib import attr
 def integration(f):
     """Mark test as an "integration" test which generally is not needed to be run
     
-    Generally tend to be slower
+    Generally tend to be slower.
+    Should be used in combination with @slow and @turtle if that is the case.
     """
     return attr('integration')(f)
 
 
 def slow(f):
     """Mark test as a slow, although not necessarily integration or usecase test
+
+    Rule of thumb cut-off to mark as slow is 10 sec
     """
     return attr('slow')(f)
 
 
+def turtle(f):
+    """Mark test as very slow, meaning to not run it on Travis due to its
+    time limit
+
+    Rule of thumb cut-off to mark as turtle is 2 minutes
+    """
+    return attr('turtle')(f)
+
+
 def usecase(f):
     """Mark test as a usecase user ran into and which (typically) caused bug report
     to be filed/troubleshooted
+
+    Should be used in combination with @slow and @turtle if slow.
     """
     return attr('usecase')(f)
